@@ -12,7 +12,7 @@ import (
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	configclientv1 "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	"github.com/openshift/library-go/pkg/controller/factory"
@@ -34,13 +34,7 @@ func NewFSyncController(operatorClient operatorv1helpers.OperatorClient, infraCl
 }
 
 func (c *FSyncController) sync(ctx context.Context, syncCtx factory.SyncContext) error {
-	transport, err := getTransport()
-	if err != nil {
-		return err
-	}
-	defer transport.CloseIdleConnections()
-
-	client, err := getPrometheusClient(ctx, c.secretClient, transport)
+	client, err := getPrometheusClient(ctx, c.secretClient)
 	if errors.IsNotFound(err) {
 		return nil
 	}
@@ -54,7 +48,7 @@ func (c *FSyncController) sync(ctx context.Context, syncCtx factory.SyncContext)
 		return err
 	}
 	leaderChanges := etcdLeaderChangesResult.(model.Vector)[0].Value
-	klog.Infof("Etcd leader changes increase in last 5m: %s", leaderChanges)
+	klog.V(4).Infof("Etcd leader changes increase in last 5m: %s", leaderChanges)
 
 	// Do nothing if there are no leader changes
 	if leaderChanges == 0.0 {
@@ -98,7 +92,7 @@ func (c *FSyncController) sync(ctx context.Context, syncCtx factory.SyncContext)
 	}
 
 	// Send warning event if excessive leader changes are detected. The event will include fsync disk metrics.
-	syncCtx.Recorder().Warningf("EtcdLeaderChangeMetrics", "Detected %s leader changes in last 5 minutes on %q disk metrics are: %s", leaderChanges, platformType, strings.Join(values, ","))
+	syncCtx.Recorder().Warningf("EtcdLeaderChangeMetrics", "Detected leader change increase of %s over 5 minutes on %q; disk metrics are: %s", leaderChanges, platformType, strings.Join(values, ","))
 
 	// TODO: Consider Degraded condition here.
 
